# MPAI CAE-ARP API

[![LICENSE](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://img.shields.io/badge/license-GPLv3-blue.svg)

## Description

This package provides a set of tools for common task in MPAI CAE-ARP standard. It is used in the official implementation of the standard and can be used as well to develop your own.

## License

This software is licensed under the GPLv3 license. See the [official site](http://www.gnu.org/licenses/gpl-3.0.html) for more information.
